package com.example.testktor.screen.auth

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.Sneaker
import com.example.testktor.authUser
import com.example.testktor.getSneakers
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android
import kotlinx.coroutines.launch

@Composable
fun MainSneakersScreen(navController: NavController) {
    var sneakers by remember { mutableStateOf<List<Sneaker>>(emptyList()) }
    val coroutineScope = rememberCoroutineScope()

    val client = HttpClient(Android)

    LaunchedEffect(Unit) {
        coroutineScope.launch {
            sneakers = getSneakers(client)
        }
    }

    SneakersContent(sneakers)
}

@Composable
fun SneakersContent(
    sneakers: List<Sneaker>
) {
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(text = "Список кроссовок", fontSize = 24.sp, modifier = Modifier.padding(bottom = 16.dp))

        LazyColumn(modifier = Modifier.fillMaxWidth()) {
            items(sneakers) { sneaker ->
                Text(text = sneaker.name, fontSize = 18.sp, modifier = Modifier.padding(8.dp))
            }
        }
    }
}